@@ -181,7 +181,9 @@ class StoredSettingsStub(api.StoredSettings):
     def set(self, key: str, value: Optional[api.JsonType], save: bool = False):
         self._settings[key] = value
 
-    def get(self, key: str, type: type[JT], default: JT = None) -> Optional[JT]:
+    def get(
+        self, key: str, type: type[JT], default: Optional[JT] = None
+    ) -> Optional[JT]:
         v = self._settings.get(key, default)
         return v if isinstance(v, type) else None
 
@@ -280,12 +282,6 @@ class OpenVarioOSStub(api.OpenVarioOS):
         self._rootfs = rootfs
         self._stub_bus_connected = asyncio.Future()
 
-    def mount_boot(self) -> None:
-        self._log.append("OS: Mount /boot")
-
-    def unmount_boot(self) -> None:
-        self._log.append("OS: Unmount /boot")
-
     def path(self, path: str) -> str:
         assert path.startswith("/"), "Absolute path is required"
         if not path.startswith("//"):
