@@ -1,4 +1,4 @@
-from typing import Coroutine, List, Optional
+from typing import Coroutine, Optional
 
 import urwid
 
@@ -88,8 +88,14 @@ class AboutActivity(api.Activity):
         ver_defs = [
             ("Openvario image", self.sys_info.get_openvario_version()),
             ("XCSoar", self._get_any_version(["xcsoar", "xcsoar-testing"])),
-            ("Sensor daemon", self._get_any_version(["sensord", "sensord-testing"]),),
-            ("Vario daemon", self._get_any_version(["variod", "variod-testing"]),),
+            (
+                "Sensor daemon",
+                self._get_any_version(["sensord", "sensord-testing"]),
+            ),
+            (
+                "Vario daemon",
+                self._get_any_version(["variod", "variod-testing"]),
+            ),
             ("Linux kernel", self.sys_info.get_kernel_version()),
             ("Hostname", self.sys_info.get_hostname()),
         ]
@@ -115,7 +121,7 @@ class AboutActivity(api.Activity):
         else:
             wdg.set_text("N/A")
 
-    async def _get_any_version(self, pkgs: List[str]) -> Optional[str]:
+    async def _get_any_version(self, pkgs: list[str]) -> Optional[str]:
         for pkgname in pkgs:
             ver = await self.sys_info.get_installed_package_version(pkgname)
             if ver is not None:
