@@ -1,5 +1,4 @@
 import asyncio
-from typing import List
 
 import pytest
 
@@ -10,7 +9,7 @@ from ovshell.device import format_nmea, is_nmea_valid, nmea_checksum, parse_nmea
 class DeviceStub(api.Device):
     id: str
     name: str
-    _stream: List[bytes]
+    _stream: list[bytes]
     _delay: float = 0
 
     def __init__(self, id: str, name: str) -> None:
@@ -20,14 +19,14 @@ class DeviceStub(api.Device):
 
     async def readline(self) -> bytes:
         if not self._stream:
-            raise IOError()
+            raise OSError()
         await asyncio.sleep(self._delay)
         return self._stream.pop() + b"\r\n"
 
     def write(self, data: bytes) -> None:
         pass
 
-    def stub_set_stream(self, values: List[bytes]) -> None:
+    def stub_set_stream(self, values: list[bytes]) -> None:
         self._stream = list(reversed(values))
 
     def stub_set_delay(self, delay: float) -> None:
@@ -69,7 +68,6 @@ def test_DeviceManagerImpl_open_nmea_empty() -> None:
         assert nmea is not None
 
 
-@pytest.mark.asyncio
 async def test_DeviceManagerImpl_get() -> None:
     # GIVEN
     devman = device.DeviceManagerImpl()
@@ -82,7 +80,6 @@ async def test_DeviceManagerImpl_get() -> None:
     assert devman.get("two") is None
 
 
-@pytest.mark.asyncio
 async def test_DeviceManagerImpl_open_nmea_stream(task_running) -> None:
     # GIVEN
     devman = device.DeviceManagerImpl()
@@ -99,7 +96,6 @@ async def test_DeviceManagerImpl_open_nmea_stream(task_running) -> None:
     assert nmea.raw_message == "$PGRMZ,+51.1,m,3*10"
 
 
-@pytest.mark.asyncio
 async def test_DeviceManagerImpl_multidevice(task_running) -> None:
     # GIVEN
     devman = device.DeviceManagerImpl()
@@ -128,13 +124,12 @@ async def test_DeviceManagerImpl_multidevice(task_running) -> None:
     assert nmea3.raw_message == "$PFLAU,0,0,0,1,0,,0,,,*4F"
 
 
-@pytest.mark.asyncio
 async def test_DeviceManagerImpl_remove_device_on_error(task_running) -> None:
     # GIVEN
     devman = device.DeviceManagerImpl()
     dev = DeviceStub("one", "One")
     devman.register(dev)
-    assert len(devman.list()) == 1
+    assert len(devman.enumerate()) == 1
 
     # WHEN
     with devman.open_nmea() as nmea_stream:
@@ -143,10 +138,9 @@ async def test_DeviceManagerImpl_remove_device_on_error(task_running) -> None:
         with pytest.raises(asyncio.TimeoutError):
             await asyncio.wait_for(read, timeout=0.01)
 
-    assert len(devman.list()) == 0
+    assert len(devman.enumerate()) == 0
 
 
-@pytest.mark.asyncio
 async def test_DeviceManagerImpl_remove_on_binary() -> None:
     # When non-ascii is received on device, drop it and try to reconnect again
     devman = device.DeviceManagerImpl()
@@ -160,10 +154,9 @@ async def test_DeviceManagerImpl_remove_on_binary() -> None:
         with pytest.raises(asyncio.TimeoutError):
             await asyncio.wait_for(nmea_stream.read(), timeout=0.05)
 
-    assert len(devman.list()) == 0
+    assert len(devman.enumerate()) == 0
 
 
-@pytest.mark.asyncio
 async def test_DeviceManagerImpl_bad_nmea() -> None:
     # GIVEN
     devman = device.DeviceManagerImpl()
